 /**************************************************************************************************|
|* Copyright 2022 Hycon Technology, Corp.                                                         *|
|* http://www.hycontek.com/                                                                       *|
|* Description:                                                                                   *|
|*                                                                                                *|
|**************************************************************************************************/

/**************************************************************************************************|
|*  Includes                                                                                      *|
|**************************************************************************************************/
#include <hy17m28sfr.h>
#include <ADC.h>
#include <PWR.h>
#include <CLK.h>
/**************************************************************************************************|
|*  Static Function                                                                               *|
|**************************************************************************************************/

/**************************************************************************************************|
|*  Generic Peripheral Library                                                                    *|
|**************************************************************************************************/

/*--------------------------------------------------------------------------------------------------------------------------------|
|  Function: ADC_Open                                                                      			     				          |
|                                                                                                 						          |
|  Parameters:                                                                                                                    |
|         cks          - [in]   DADC_DHSCKDIV16  /  DADC_DHSCKDIV8                                                                |
|								DADC_DHSCKDIV4   /  DADC_DHSCKDIV2                                                                |
|         inp          - [in]   INP_AI0	   /  INP_AI1   /  INP_AI2   /  INP_AI3   /  INP_AI6   /  INP_AI7         		          |
|								INP_AI8    /  INP_Rinp  /  INP_Rinn  /  INP_V12   /  INP_OPOI  /  INP_VDDA        		          |
|								INP_REFOI  /  INP_TSP0  /  INP_TSP1  /  INP_VSS   /  INP_AI9   /  INP_AI10                        |
|                               INP_TKP    /  INP_TKN   /  INP_AI11  /  INP_AI12  /  INP_AI13  /  INP_AI14                        |
|         inn          - [in]   INN_AI0    /  INN_AI1   /  INN_AI2   /  INN_AI3       /  INN_AI5   /  INN_AI7         	          |
|							   	INN_Rinp   /  INN_Rinn  /  INN_V12   /  INN_VDDDIV10  /  INN_OPOI  /  INN_VDDA	                  |
|							    INN_REFOI  /  INN_TSN0  /  INN_TSN1  /  INN_VSS       /  INN_AI8   /  INN_AI9                     |
|							    INN_AI10   /  INN_TKP   /  INN_TKN   /  INN_AI11      /  INN_AI12  /  INN_AI13                    |
|							    INN_AI14                                                                                          |
|         vrh          - [in]   VRH_VDDA  /  VRH_Rinn  /  VRH_AI7   /  VRH_V12SEL                                                 |
|         vr           - [in]   VRL_VSS   /  VRL_AI9   /  VRL_AI10  /  VRL_REFOI                                                  |
|         adgn         - [in]   ADGN_RSVD   /  ADGN_16  /  ADGN_8  /  ADGN_4  /  ADGN_2  /  ADGN_1                                |
|                               ADGN_1DIV2  /  ADGN_1DIV4                                                                         |
|         vrgn         - [in]   VREGN_DIV2	/	VREGN_DIV1                                                                        |
|         dcset        - [in]   DCSET_N7DIV8  /  DCSET_N6DIV8  /  DCSET_N5DIV8  /  DCSET_N4DIV8                                   |
|                               DCSET_N3DIV8  /  DCSET_N2DIV8  /  DCSET_N1DIV8  /  DCSET_N0                                       |
|                               DCSET_P7DIV8  /  DCSET_P6DIV8  /  DCSET_P5DIV8  /  DCSET_P4DIV8                                   |
|                               DCSET_P3DIV8  /  DCSET_P2DIV8  /  DCSET_P1DIV8  /  DCSET_P0                                       |
|         osr          - [in]   OSR_64    /  OSR_128   /  OSR_256    /  OSR_512    /  OSR_1024  /  OSR_2048                       |
|                               OSR_4096  /  OSR_8192  /  OSR_16384  /  OSR_32768  /  OSR_65536                                   |
|  Returns:                                                                               		                                  |
|         None               		                   		                   		                   		                      |
|                                                                                       		                   		          |
|  Description:                                                                                							          |
|         This function is used to open the ADC                     													          |
|--------------------------------------------------------------------------------------------------------------------------------*/
void ADC_Open( unsigned char cks,   //Prescaler of SD18 peripheral operating frequency
              unsigned char inp,   //SI+ input signal selector
              unsigned char inn,   //SI- input signal selector
              unsigned char vrh,   //VR+ voltage signal selector
              unsigned char vrl,   //VR- voltage signal selector
              unsigned char adgn,  //AD amplification adjuster
              unsigned char vrgn,  //VR amplification adjuster
              unsigned char dcset, //SI+/- bias adjuster
              unsigned char osr)  //SD18 over-sampling rate divider

{
    // ADC CLK setting //
    CLK_ADCCKDivSelect(cks);

    // ADC Init //
    ADC_VINSelect(inp,inn);
    ADC_VRINSelect(vrh,vrl);            // Config ADC Ref. Voltage Input Channel
    ADC_GainSelect(adgn,vrgn);          // Config VRE Gain and AD Gain
    ADC_DCSETSelect(dcset);             // Config DC offset
    ADC_OSRSelect(osr);                 // Config Over sampling ratio

    PWR_ENACMEnable();
    ADC_Enable();							//ADC Enable
    //==========Setup ADC INT======================================
	ADC_INT_ClearFlag();      //Clear ADIF
	ADC_INT_Enable();   //ADC INT Enable
	ADC_Enable();         //ADC Enable
	ADC_CMFREnable();     //CMFR=1, Comb Filter Reset
}

/*-------------------------------------------------------------------------------------------------|
|  Function: ADC_GetData                                                                           |
|                                                                                                  |
|  Parameters:                                                                                     |
|         None                                                                                     |
|                                                                                                  |
|  Returns:                                                                                        |
|         ADCData   - [in] Read the 24-bit data for ADCR                                           |
|                                                                                                  |
|  Description:                                                                                    |
|         This function is used to Read the Data for ADC                                           |
|-------------------------------------------------------------------------------------------------*/
long ADC_GetData(void)
{
  long ADCData;
  ((char *)(&ADCData))[0] = AD1L;
  ((char *)(&ADCData))[1] = AD1M;
  ((char *)(&ADCData))[2] = AD1H;

  if (((char *)(&ADCData))[2]>0x80)
    ((char *)(&ADCData))[3] = 0xFF;
  else
    ((char *)(&ADCData))[3] = 0x00;
  return ADCData;
}
