/**************************************************************************************************|
|* Copyright 2022 Hycon Technology, Corp.                                                         *|
|* http://www.hycontek.com/                                                                       *|
|* Description:                                                                                   *|
|*                                                                                                *|
|**************************************************************************************************/

/**************************************************************************************************|
|*  Includes                                                                                      *|
|**************************************************************************************************/
#include <hy17m28sfr.h>
#include <BIE.h>
/**************************************************************************************************|
|*  Static Function                                                                               *|
|**************************************************************************************************/

/**************************************************************************************************|
|*  Generic Peripheral Library                                                                    *|
|**************************************************************************************************/

/*-------------------------------------------------------------------------------------------------|
|  Function: BIE_EEPMode                                                                           |
|                                                                                                  |
|  Parameters:                                                                                     |
|         eemode -    [in] EEMODE_64bytes / EEMODE_32bytes                                         |
|                                                                                                  |
|  Returns:                                                                                        |
|         None                                                                                     |
|                                                                                                  |
|  Description:                                                                                    |
|         This function is used to setting EEPROM mode                                             |
|-------------------------------------------------------------------------------------------------*/
void BIE_EEPMode(unsigned char eemode)
{
    BIE_EEPModeSel(eemode);
    EECR2= 0x5A;      //EEPROM mode setting done, then EECR2=0x5A reload EEPROM data
	__asm__ ("NOP");  //Wait a NOP instruction time after write EERC2 register
}

/*-------------------------------------------------------------------------------------------------|
|  Function: BIE_DataReload                                                                           |
|                                                                                                  |
|  Parameters:                                                                                     |
|         None                                                                                     |
|                                                                                                  |
|  Returns:                                                                                        |
|         None                                                                                     |
|                                                                                                  |
|  Description:                                                                                    |
|         Reload BIE data into EERD0~EERD63                                             |
|-------------------------------------------------------------------------------------------------*/
void BIE_DataReload(void)
{
	BIE_EEPReload();
	__asm__ ("NOP");  //Wait a NOP instruction time after write EERC2 register
}

/*-------------------------------------------------------------------------------------------------|
|  Function: BIE_DataWrite                                                                           |
|                                                                                                  |
|  Parameters:                                                                                     |
|         None                                                                                     |
|                                                                                                  |
|  Returns:                                                                                        |
|         None                                                                                     |
|                                                                                                  |
|  Description:                                                                                    |
|         Write BIE data from EERD0~EERD63                                             |
|-------------------------------------------------------------------------------------------------*/
void BIE_DataWrite(void)
{
	BIEKEY= 0x69;
	BIE_EEPWrite();
    __asm__ ("NOP");  //Wait a NOP instruction time after write EERC2 register
    BIEKEY= 0;
}
/**************************************************************************************************|
|*  Static Functions                                                                              *|
|**************************************************************************************************/
