/**************************************************************************************************|
|* Copyright 2022 Hycon Technology, Corp.                                                          *|
|* http://www.hycontek.com/                                                                       *|
|* Description:                                                                                   *|
|* - Generic Peripheral Library: A general and functional Interface for the specific Peripheral   *|
|* - Low Level Peripheral Access: Register-Bits Level access Macro, user must take care           *|
|*   of calling procedure and hardware constraints                                                *|
|* - Support Target: HY17M Series                                                                 *|
|**************************************************************************************************/


/**************************************************************************************************|
|*                               Peripheral Register Bits field                                   *|
|**************************************************************************************************/

// LNAMP0 //
#define TR2Chop                    4
#define TR2Chop_MSK               (1 << TR2Chop)
#define TR2Chop_Negative          (1 << TR2Chop)
#define TR2Chop_Positive          (0 << TR2Chop)

#define TR1Chop                    3
#define TR1Chop_MSK               (1 << TR1Chop)
#define TR1Chop_Negative          (1 << TR1Chop)
#define TR1Chop_Positive          (0 << TR1Chop)

#define VRPOS                      2
#define VRPOS_MSK                 (1 << VRPOS)
#define VRPOS_Rinp                (1 << VRPOS)
#define VRPOS_OFF                 (0 << VRPOS)

// LNAMP1 //
#define ENPGA                      7
#define ENPGA_MSK                 (1 << ENPGA)
#define ENPGA_ENABLE              (1 << ENPGA)
#define ENPGA_DISABLE             (0 << ENPGA)

#define INPS                  4
#define INPS_MSK             (3 << INPS)
#define INPS_RSVD            (3 << INPS)
#define INPS_TR2             (2 << INPS)
#define INPS_V12             (1 << INPS)
#define INPS_TR1             (0 << INPS)

#define PGAG                   2
#define PGAG_MSK              (3 << PGAG)
#define PGAG_RSVD             (3 << PGAG)
#define PGAG_40               (2 << PGAG)
#define PGAG_20               (1 << PGAG)
#define PGAG_10               (0 << PGAG)

/**************************************************************************************************|
|*                                      Function Level                                            *|
|**************************************************************************************************/

/*-------------------------------------------------------------------------------------------------|
|  Function-like Macro:                                                                            |
|    Register Bits field Configuration without function call overhead,                             |
|    user should take care of detail of h/w behavior and constrains.                               |
|-------------------------------------------------------------------------------------------------*/
#define PGA_TR1ChopON()               (LNAMP0 |= TR1Chop_Negative)
#define PGA_TR1ChopOFF()              (LNAMP0 &= (~TR1Chop_MSK))
#define PGA_TR2ChopON()               (LNAMP0 |= TR2Chop_Negative)
#define PGA_TR2ChopOFF()              (LNAMP0 &= (~TR2Chop_MSK))
#define PGA_NTCRefResistance(vrpos)   (LNAMP0 = ((LNAMP0 & (~VRPOS_MSK)) | vrpos))

#define PGA_Enable()                  (LNAMP1 |= ENPGA_ENABLE)
#define PGA_Disable()                 (LNAMP1 &= (~ENPGA_MSK))
#define PGA_InputSelect(inps)          (LNAMP1 = ((LNAMP1 & (~INPS_MSK)) | inps))
#define PGA_PGAGainSelect(pgag)          (LNAMP1 = ((LNAMP1 & (~PGAG_MSK)) | pgag))


/*-------------------------------------------------------------------------------------------------|
|  Function call:                                                                                  |
|    For general and functional register access.                                                   |
|-------------------------------------------------------------------------------------------------*/
		   				