/**************************************************************************************************|
|* Copyright 2022 Hycon Technology, Corp.                                                         *|
|* http://www.hycontek.com/                                                                       *|
|* Description:                                                                                   *|
|*                                                                                                *|
|**************************************************************************************************/

/**************************************************************************************************|
|*  Includes                                                                                      *|
|**************************************************************************************************/
#include <hy17m28sfr.h>
#include <PWR.h>
#include <ADC.h>
/**************************************************************************************************|
|*  Static Function                                                                               *|
|**************************************************************************************************/

/**************************************************************************************************|
|*  Generic Peripheral Library                                                                    *|
|**************************************************************************************************/
/*----------------------------------------------------------------------------------------------------------------------|
|  Function: PWR_VDDAOpen                                                                                               |
|                                                                                                                       |
|  Parameters:                                                                                                          |
|         vdda  		  - [in]  LDOC_2V4  / LDOC_2V6 / LDOC_2V9 / LDOC_3V3                                            |
|                                 LDOC_3V6  / LDOC_4V0 / LDOC_4V5 / LDOC_5V0                                            |
|                                                                                                                       |
|  Returns:                                                                                                             |
|         None                                                                                                          |
|                                                                                                                       |
|  Description:                                                                                                         |
|         This function is used to open the PWR of VDDA                                                                 |
|----------------------------------------------------------------------------------------------------------------------*/
void PWR_VDDAOpen(unsigned char vdda)    //VDDA regulated selector
{
	PWR_LDOPLEnable();	
	PWR_VDDASel(vdda);		//VDDA Voltage Selection
	PWR_LDOMode(LDOM_DISABLE);
    PWR_LDOEnable();		  //Enable VDDA
	
}

/*----------------------------------------------------------------------------------------------------------------------|
|  Function: PWR_ACMintOpen                                                                                             |
|                                                                                                                       |
|  Parameters:                                                                                                          |
|         acm   		  - [in]  SELVIN_VDDADIV2  / SELVIN_V12                                                         |
|                                                                                                                       |
|  Returns:                                                                                                             |
|         None                                                                                                          |
|                                                                                                                       |
|  Description:                                                                                                         |
|         This function is used to open the PWR of ACMint, need to enable VDDA on first                                 |
|----------------------------------------------------------------------------------------------------------------------*/
void PWR_ACMintOpen(unsigned char acm)   //ACMint enable and voltage source selection
{
	PWR_ACMintSource(acm);
	PWR_ENACMEnable();	
}

/*----------------------------------------------------------------------------------------------------------------------|
|  Function: PWR_REFOOpen                                                                                               |
|                                                                                               				        |
|  Parameters:                                                                                                          |
|         refovol  		  - [in] REFOS_1V2  / REFOS_2V0 / REFOS_2V4 / REFOS_3V0                                         |
|         output  		  - [in] REFO1_NOPAD  : REFO voltage not output to PAD                                          |
|                                REFO1_PT10   : REFO voltage output to PT1.0                                            |
|                                                                                                                       |
|  Returns:                                                                                                             |
|         None                                                                                                          |
|                                                                                                                       |
|  Description:                                                                                                         |
|         This function is used to open the PWR of REFO, need to enable VDDA on first                                   |
|----------------------------------------------------------------------------------------------------------------------*/
void PWR_REFOOpen(unsigned char refovol, unsigned char refo1)    //REFO enalbe and voltage, output mode selection
{
    PWR_REFOVoltage(refovol);
    PWR_REFOEnable(); 
    PWR_REFOOutput(refo1);
}
/**************************************************************************************************|
|*  Static Functions                                                                              *|
|**************************************************************************************************/
