/**************************************************************************************************|
|* Copyright 2022 Hycon Technology, Corp.                                                         *|
|* http://www.hycontek.com/                                                                       *|
|* Description:                                                                                   *|
|* - Generic Peripheral Library: A general and functional Interface for the specific Peripheral   *|
|* - Low Level Peripheral Access: Register-Bits Level access Macro, user must take care           *|
|*   of calling procedure and hardware constraints                                                *|
|* - Support Target: HY17M Series                                                                 *|
|**************************************************************************************************/

/**************************************************************************************************|
|*                               Peripheral Register Bits field                                   *|
|**************************************************************************************************/
#include <ADC.h>


// PWRCN //
#define ENBGR                      7
#define ENBGR_MSK                 (1 << ENBGR)
#define ENBGR_ENABLE              (1 << ENBGR)
#define ENBGR_DISABLE             (0 << ENBGR)

//Please refer to the Datasheet for LDOC typical voltage
#define LDOC                       4
#define LDOC_MSK                  (7 << LDOC)
#define LDOC_5V0                  (7 << LDOC)
#define LDOC_4V5                  (6 << LDOC)
#define LDOC_4V0                  (5 << LDOC)
#define LDOC_3V6                  (4 << LDOC)
#define LDOC_3V3                  (3 << LDOC)
#define LDOC_2V9                  (2 << LDOC)
#define LDOC_2V6                  (1 << LDOC)
#define LDOC_2V4                  (0 << LDOC)

#define LDOM                       2
#define LDOM_MSK                  (3 << LDOM)
#define LDOM_BLOUT                (3 << LDOM)
#define LDOM_HIGH                 (2 << LDOM)
#define LDOM_VDD                  (1 << LDOM)
#define LDOM_DISABLE              (0 << LDOM)

#define ENLDO                      1                
#define ENLDO_MSK                 (1 << ENLDO)
#define ENLDO_ENABLE              (1 << ENLDO)
#define ENLDO_DISABLE             (0 << ENLDO)

// AD1CN1 //
#define REFO1                      6
#define REFO1_MSK                 (1 << REFO1)
#define REFO1_PT10                (1 << REFO1)
#define REFO1_NOPAD               (0 << REFO1)

//Please refer to the Datasheet for REFOS typical voltage
#define REFOS                      3
#define REFOS_MSK                 (3 << REFOS)
#define REFOS_3V0                 (3 << REFOS)
#define REFOS_2V4                 (2 << REFOS)
#define REFOS_2V0                 (1 << REFOS)
#define REFOS_1V2                 (0 << REFOS)

//AD1CN2 //
#define SELVIN                      4
#define SELVIN_MSK                 (1 << SELVIN)
#define SELVIN_VDDADIV2            (1 << SELVIN)
#define SELVIN_V12                 (0 << SELVIN)

//AD1CN5//
#define ENACM                      7                
#define ENACM_MSK                 (1 << ENACM)
#define ENACM_ENABLE              (1 << ENACM)
#define ENACM_DISABLE             (0 << ENACM)

#define VCMS                      5                
#define VCMS_MSK                 (1 << VCMS)
#define VCMS_REFOint             (1 << VCMS)
#define VCMS_ACMint              (0 << VCMS)

#define LDOPL                     4                
#define LDOPL_MSK                (1 << LDOPL)
#define LDOPL_ENABLE             (1 << LDOPL)
#define LDOPL_DISABLE            (0 << LDOPL)

#define ENREFO                    3                
#define ENREFO_MSK               (1 << ENREFO)
#define ENREFO_ENABLE            (1 << ENREFO)
#define ENREFO_DISABLE           (0 << ENREFO)

// MCCN1 //
#define VRSEL                     6                
#define VRSEL_MSK                (1 << VRSEL)
#define VRSEL_ACMint             (1 << VRSEL)
#define VRSEL_REFOint            (0 << VRSEL)

/**************************************************************************************************|
|*                                      Function Level                                            *|
|**************************************************************************************************/

/*-------------------------------------------------------------------------------------------------|
|  Function-like Macro:                                                                            |
|    Register Bits field Configuration without function call overhead,                             |
|    user should take care of detail of h/w behavior and constrains.                               |
|-------------------------------------------------------------------------------------------------*/
#define PWR_BGREnable()                 (PWRCN |= ENBGR_ENABLE)
#define PWR_BGRDisable()                (PWRCN &= (~ENBGR_MSK))
#define PWR_LDOEnable()                 (PWRCN |= ENLDO_ENABLE)
#define PWR_LDODisable()                (PWRCN &= (~ENLDO_MSK))
#define PWR_VDDASel(Sel)                (PWRCN = ((PWRCN & (~LDOC_MSK)) | Sel))
#define PWR_LDOMode(Sel)                (PWRCN = ((PWRCN & (~LDOM_MSK)) | Sel))

#define PWR_REFOVoltage(refos)       (AD1CN1 = ((AD1CN1 & (~REFOS_MSK)) | refos))
#define PWR_REFOOutput(refo1)       (AD1CN1 = ((AD1CN1 & (~REFO1_MSK)) | refo1))

#define PWR_ACMintSource(selvin)       (AD1CN2 = ((AD1CN2 & (~SELVIN_MSK)) | selvin))
//#define ADC_ACMintSource(SELVINSel)	    (AD1CN2 = ((AD1CN2 & (~SELVIN_MSK)) | SELVINSel))
#define PWR_LDOPLEnable()               (AD1CN5 |= LDOPL_ENABLE)
#define PWR_LDOPLDisable()              (AD1CN5 &= (~LDOPL_MSK))
//#define ADC_LDOPLEnable()               (AD1CN5 |= LDOPL_ENABLE)
//#define ADC_LDOPLDisable()              (AD1CN5 &= (~LDOPL_MSK))
#define PWR_ENACMEnable()               (AD1CN5 |= ENACM_ENABLE)
#define PWR_ENACMDisable()              (AD1CN5 &=(~ENACM_MSK))
//#define ADC_ENACMEnable()               (AD1CN5 |= ENACM_ENABLE)
//#define ADC_ENACMDisable()              (AD1CN5 &=(~ENACM_MSK))
#define PWR_VCMSSelect(vcms)           (AD1CN5 = ((AD1CN5 & (~VCMS_MSK)) | vcms))
//#define ADC_VCMSSelect(vcms)           (AD1CN5 = ((AD1CN5 & (~VCMS_MSK)) | vcms))
#define PWR_REFOEnable()               (AD1CN5 |= ENREFO_ENABLE)
#define PWR_REFODisable()              (AD1CN5 &= (~ENREFO_MSK)); \ (AD1CN1 &= (~REFO1_MSK));  //REFO1=0 & ENREFO=0

#define PWR_REFOISource(vrsel)       (MCCN1 = ((MCCN1 & (~VRSEL_MSK)) | vrsel))
/*-------------------------------------------------------------------------------------------------|
|  Function call:                                                                                  |
|    For general and functional register access.                                                   |
|-------------------------------------------------------------------------------------------------*/
void PWR_VDDAOpen(unsigned char vdda);    //VDDA regulated selector
void PWR_ACMintOpen(unsigned char acm);  //ACMint enable and voltage source selection
void PWR_REFOOpen(unsigned char refovol, unsigned char refo1);    //REFO ENABLE and voltage,output mode selection
