/**************************************************************************************************|
|* Copyright 2022 Hycon Technology, Corp.                                                         *|
|* http://www.hycontek.com/                                                                       *|
|* Description:                                                                                   *|
|* - Generic Peripheral Library: A general and functional Interface for the specific Peripheral   *|
|* - Low Level Peripheral Access: Register-Bits Level access Macro, user must take care           *|
|*   of calling procedure and hardware constraints                                                *|
|* - Support Target: HY17M Series                                                                 *|
|**************************************************************************************************/
 
/**************************************************************************************************|
|*                               Peripheral Register Bits field                                   *|
|**************************************************************************************************/
// TKCN1 //
#define ENTP                       7
#define ENTP_MSK                  (1 << ENTP)
#define ENTP_ENABLE               (1 << ENTP)
#define ENTP_DISABLE              (0 << ENTP)

#define RxRI                       5
#define RxRI_MSK                  (3 << BZ)
#define RxRI_400K                 (3 << BZ)
#define RxRI_200K                 (2 << BZ)
#define RxRI_100K                 (1 << BZ)
#define RxRI_50K                  (0 << BZ)

#define RxCI                       3
#define RxCI_MSK                  (3 << BZ)
#define RxCI_16p                  (3 << BZ)
#define RxCI_8p                   (2 << BZ)
#define RxCI_4p                   (1 << BZ)
#define RxCI_2p                   (0 << BZ)

#define RxCoff                     0
#define RxCoff_MSK                (7 << RxCoff)
#define RxCoff_8p                 (7 << RxCoff)
//#define RxCoff_                   (6 << RxCoff)
//#define RxCoff_                   (5 << RxCoff)
//#define RxCoff_                   (4 << RxCoff)
#define RxCoff_4p                 (3 << RxCoff)
#define RxCoff_2p                 (2 << RxCoff)
#define RxCoff_1p                 (1 << RxCoff)
#define RxCoff_0p                 (0 << RxCoff)

// TKCN2 //
#define TXADCKCNT                 4
#define TXADCKCNT_MSK            (15 << TXADCKCNT)

#define RxCfb                     2
#define RxCfb_MSK                (3 << RxCfb)
#define RxCfb_40p                (3 << RxCfb)
#define RxCfb_30p                (2 << RxCfb)
#define RxCfb_20p                (1 << RxCfb)
#define RxCfb_10p                (0 << RxCfb)

#define TPCLK                     0
#define TPCLK_MSK                (3 << TPCLK)
#define TPCLK_HAODIV16           (3 << TPCLK)
#define TPCLK_HAODIV8            (2 << TPCLK)
#define TPCLK_HAODIV4            (1 << TPCLK)
#define TPCLK_HAODIV2            (0 << TPCLK)

// TKCN3 //
#define MRx                       6
#define MRx_MSK                  (1 << MRx)
#define MRx_Dual                 (1 << MRx)
#define MRx_Single               (0 << MRx)

#define RxMx                     4
#define RxMx_MSK                (3 << RxMx)
//#define RxMx_Rsv                (3 << RxMx)
#define RxMx_RX2                (2 << RxMx)
#define RxMx_RX1                (1 << RxMx)
#define RxMx_Offset             (0 << RxMx)

#define TxSettle                 1
#define TxSettle_MSK            (7 << TxSettle)
#define TxSettle_7Clock         (7 << TxSettle)
#define TxSettle_6Clock         (6 << TxSettle)
#define TxSettle_5Clock         (5 << TxSettle)
#define TxSettle_4Clock         (4 << TxSettle)
#define TxSettle_3Clock         (3 << TxSettle)
#define TxSettle_2Clock         (2 << TxSettle)
#define TxSettle_1Clock         (1 << TxSettle)
#define TxSettle_DIV2Clock      (0 << TxSettle)

#define TKCMS                    0
#define TKCMS_MSK               (1 << TKCMS)
#define TKCMS_ACMBuffer         (1 << TKCMS)
#define TKCMS_TKBuffer          (0 << TKCMS)


/**************************************************************************************************|
|*                                      Function Level                                            *|
|**************************************************************************************************/

/*-------------------------------------------------------------------------------------------------|
|  Function-like Macro:                                                                            |
|    Register Bits field Configuration without function call overhead,                             |
|    user should take care of detail of h/w behavior and constrains.                               |
|-------------------------------------------------------------------------------------------------*/
#define TP_Enable()                    (TKCN1 |=  ENTP_ENABLE)
#define TP_Disable()                   (TKCN1 &=  ~ENTP_MSK)
#define TP_RISelect(ri)                (TKCN1 = ((TKCN1 & (~RxRI_MSK)) | ri))
#define TP_CISelect(ci)                (TKCN1 = ((TKCN1 & (~RxCI_MSK)) | ci))
#define TP_CoffsetSelect(coffset)      (TKCN1 = ((TKCN1 & (~RxCoff_MSK)) | coffset))

#define TP_TxOUTCount(count)           (TKCN2 = ((TKCN2 & (~TXADCKCNT_MSK)) | (count<<TXADCKCNT))
#define TP_CfbSelect(cfb)              (TKCN2 = ((TKCN2 & (~RxCfb_MSK)) | cfb))
#define TP_CKDivSelect(tpck)           (TKCN2 = ((TKCN2 & (~TPCLK_MSK)) | tpck))

#define TP_MeasureChSet(mrx)           (TKCN3 = ((TKCN3 & (~MRx_MSK)) | mrx))
#define TP_MeasureOrder(rxmx)          (TKCN3 = ((TKCN3 & (~RxMx_MSK)) | rxmx))
#define TP_StabilizeTime(txsettle)     (TKCN3 = ((TKCN3 & (~TxSettle_MSK)) | txsettle))
#define TP_CommonVoltageSel(tkcms)        (TKCN3 = ((TKCN3 & (~TKCMS_MSK)) | tkcms))
/*-------------------------------------------------------------------------------------------------|
|  Function call:                                                                                  |
|    For general and functional register access.                                                   |
|-------------------------------------------------------------------------------------------------*/
