/**************************************************************************************************|
|* Copyright 2022 Hycon Technology, Corp.                                                         *|
|* http://www.hycontek.com/                                                                       *|
|* Description:                                                                                   *|
|*                                                                                                *|
|**************************************************************************************************/

/**************************************************************************************************|
|*  Includes                                                                                      *|
|**************************************************************************************************/
#include <hy17m28sfr.h>
#include <UART.h>
#include <GPIO.h>
#include <INT.h>

/**************************************************************************************************|
|*  Static Function                                                                               *|
|**************************************************************************************************/

/**************************************************************************************************|
|*  Generic Peripheral Library                                                                    *|
|**************************************************************************************************/

/*---------------------------------------------------------------------------------------------------------------------------------|
|  Function: UART0_Open                                                                                                            |
|                                                                                                                                  |
|  Parameters:                                                                                                                     |
|         uBRGR     - [in] Desired baud rate.                                                                                      |
|         uDataBits - [in] "8"                 *8 bit mode*                                                                        |
|                          "9"                 *9 bit mode*                                                                        |
|         uParity   - [in] PARITY_ODD / PARITY_Even / PARITY_None                                                                  |
|                                                                                                                                  |
|  Returns:                                                                                                                        |
|         None                                                                                                                     |
|                                                                                                                                  |
|  Description:                                                                                                                    |
|         This function is used to open                                                                                            |
|                  the Enhanced Universal Asynchronous Receiver Transmitter(UART)                                                  |
|---------------------------------------------------------------------------------------------------------------------------------*/
void UART0_Open(unsigned int uBG0R,     //desired baud rate
               unsigned char uDataBits, //Enable the transmission of the ninth bit and send the ninth bit data
               unsigned char uParity)     //Odd/even bit check
{

	BG0RH=(uBG0R>>8);
	BG0RL= (0x00FF & uBG0R);

    if (uDataBits==9)
    {
        UART0_TX9Enable();
        UART0_RC9Enable();
    }
    else
    {
        UART0_TX9Disable();
        UART0_RC9Disable();
    }
    UART0_Parity(uParity);
    UART0_TXEnable();
    UART0_CREnable(); 		    
    UART0_Enable();	
    
}
/*---------------------------------------------------------------------------------------------------------------------------------|
|  Function: UART0_BGRSet                                                                                                          |
|                                                                                                                                  |
|  Parameters:                                                                                                                     |
|         uBG0R     - [in] UART send data                                                                                          |
|                                                                                                                                  |
|  Returns:                                                                                                                        |
|         None                                                                                                                     |
|                                                                                                                                  |
|  Description:                                                                                                                    |
|         This function is used to set the UART send data                                                                          |
|                                                                                                                                  |
|---------------------------------------------------------------------------------------------------------------------------------*/
void UART0_BGRSet(unsigned int uBG0R)
{
	BG0RH=(uBG0R>>8);
	BG0RL= (0x00FF & uBG0R);
}
